@@ -13,28 +13,28 @@
 #   including module, all works correctly and transparently.
 #
 package CGI::WebOut;
-our $VERSION = "2.20";
+our $VERSION = "2.21";
 
 use strict;
 use Exporter; our @ISA=qw(Exporter);
 our @EXPORT=qw(
-	ER_NoErr
-	ER_Err2Browser 
-	ER_Err2Comment 
-	ER_Err2Plain
-	ErrorReporting
-	grab
-	echo  
-	SetAutoflush 
-	NoAutoflush 
-	UseAutoflush 
-	Header
-	HeadersSent
-	Redirect
-	ExternRedirect
-	NoCache
-	Flush
-	try catch warnings throw
+  ER_NoErr
+  ER_Err2Browser 
+  ER_Err2Comment 
+  ER_Err2Plain
+  ErrorReporting
+  grab
+  echo  
+  SetAutoflush 
+  NoAutoflush 
+  UseAutoflush 
+  Header
+  HeadersSent
+  Redirect
+  ExternRedirect
+  NoCache
+  Flush
+  try catch warnings throw
 );
 
 
@@ -115,32 +115,32 @@ our $rCurBuf;                    #
 #     ,   . 
 my $numReties;
 sub retieSTDOUT
-{	my ($needRestart) = @_;
-	$needRestart ||= !$numReties++;
-	# Handle all warnings and errors.
-	$SIG{__WARN__} = sub { &Warning(($_[0] !~ /^\w+:/ ? "Warning: " : "").shift) };
-	$SIG{__DIE__} = sub { return if ref $_[0]; &Warning(($_[0] !~ /^\w+:/ ? "Fatal: " : "").shift) };
-	#    ,    .
-	if ($needRestart) {
-		$HeadersSent = $Redirected = $NoCached = 0;
-		@Headers = ();
-		$$rRootBuf = '';
-	}
-	#    , 
-	return if tied(*STDOUT) && ref tied(*STDOUT) eq __PACKAGE__."::Tie";
-	tie(*STDOUT, __PACKAGE__."::Tie", \*STDOUT, tied(*STDOUT));
+{ my ($needRestart) = @_;
+  $needRestart ||= !$numReties++;
+  # Handle all warnings and errors.
+  $SIG{__WARN__} = sub { &Warning(($_[0] !~ /^\w+:/ ? "Warning: " : "").shift) };
+  $SIG{__DIE__} = sub { return if ref $_[0]; &Warning(($_[0] !~ /^\w+:/ ? "Fatal: " : "").shift) };
+  #    ,    .
+  if ($needRestart) {
+    $HeadersSent = $Redirected = $NoCached = 0;
+    @Headers = ();
+    $$rRootBuf = '';
+  }
+  #    , 
+  return if tied(*STDOUT) && ref tied(*STDOUT) eq __PACKAGE__."::Tie";
+  tie(*STDOUT, __PACKAGE__."::Tie", \*STDOUT, tied(*STDOUT));
 }
 
 
 # ,    Web-  
 sub IsWebMode() { 
-	return $ENV{SCRIPT_NAME}? 1 : 0 
+  return $ENV{SCRIPT_NAME}? 1 : 0 
 }
 
 
 #   ?
 sub HeadersSent { 
-	return $HeadersSent;
+  return $HeadersSent;
 }
 
 
@@ -149,18 +149,18 @@ sub HeadersSent {
 #     ,  Flush().
 #    .
 sub echo {
-	#    undef-     ,
-	#   print.
-	if(grep {!defined $_} @_) {
-		#    -  ,    .
-		eval { require Carp } 
-			and Carp::carp("Use of uninitialized value in print"); 
-	}
-	my $txt = join("", map { defined $_? $_:"" } @_); 
-	return if $txt eq "";
-	$$rCurBuf .= $txt;
-	Flush() if $UseAutoflush && $rCurBuf == $rRootBuf;
-	return length($txt);
+  #    undef-     ,
+  #   print.
+  if(grep {!defined $_} @_) {
+    #    -  ,    .
+    eval { require Carp } 
+      and Carp::carp("Use of uninitialized value in print"); 
+  }
+  my $txt = join("", map { defined $_? $_:"" } @_); 
+  return if $txt eq "";
+  $$rCurBuf .= $txt;
+  Flush() if $UseAutoflush && $rCurBuf == $rRootBuf;
+  return length($txt);
 }
 
 
@@ -173,116 +173,117 @@ sub echo {
 #   ,   catch: 
 # $grabbed = grab { print 'Hello!' };
 sub grab(&@)
-{	my ($func, $catch)=@_;
-	my $Buf = CGI::WebOut->new; 
-	$@ = undef; eval { &$func() };
-	if ($@ && $catch) { chomp($@); local $_ = $@; &$catch; }
-	return $Buf->buf;
+{ my ($func, $catch)=@_;
+  my $Buf = CGI::WebOut->new; 
+  $@ = undef; eval { &$func() };
+  if ($@ && $catch) { chomp($@); local $_ = $@; &$catch; }
+  return $Buf->buf;
 }
 
 
 # static Header($header)
 #   .
 sub Header($)
-{	my ($head)=@_;
-	if ($HeadersSent) {
-		eval { require Carp } 
-			and Carp::carp("Oops... Header('$head') called after content had been sent to browser!\n"); 
-		return undef; 
-	}
-	push(@Headers, $head);
-	return 1;
+{ my ($head)=@_;
+  if ($HeadersSent) {
+    eval { require Carp } 
+      and Carp::carp("Oops... Header('$head') called after content had been sent to browser!\n"); 
+    return undef; 
+  }
+  push(@Headers, $head);
+  return 1;
 }
 
 
 #      .
-sub Flush() {	
-	#    Perl-
-	local $| = 1;	
-	#     ,  
-	if (!$HeadersSent && IsWebMode()) {
-		my $ContType="text/html";
-		unshift(@Headers,"X-Powered-By: CGI::WebOut v$VERSION (http://www.dklab.ru/chicken/4.html) by Dmitry Koteroff, (C) 2000-2004.");
-		#  Content-type,      
-		for (my $i=0; $i<@Headers; $i++) {
-			if ($Headers[$i]=~/^content-type: *(.*)$/i) {
-				$ContType = $1; splice(@Headers, $i, 1); $i--;
-				next;
-			}
-			if ($Headers[$i]=~m/^location: /i) {
-				$Redirected = 1;
-			}
-		}
-		push(@Headers, "Content-type: $ContType");
-		my $headers = join("\n",@Headers)."\n\n";
-		if (!$Redirected) {
-			# Prepend the output buffer with headers data.
-			# So we output the buffer and headers in ONE print call (it is 
-			# more transparent for calling code if it ties STDOUT by himself).
-			$$rRootBuf = $headers.$$rRootBuf;
-		} else {
-			# Only headers should be sent. 
-			_RealPrint($headers);
-		}
-		$HeadersSent = 1;
-	}
-	#     
-	_Debug("Flush: len=%d", length($$rRootBuf));
-	if (!$Redirected) { 
-		_RealPrint($$rRootBuf);
-	}
-	$$rRootBuf = "";
-	return 1;
+sub Flush() { 
+  #    Perl-
+  local $| = 1; 
+  #     ,  
+  if (!$HeadersSent && IsWebMode()) {
+    my $ContType="text/html";
+    unshift(@Headers,"X-Powered-By: CGI::WebOut v$VERSION (http://www.dklab.ru/chicken/4.html), (C) by Dmitry Koterov");
+    #  Content-type,      
+    for (my $i=0; $i<@Headers; $i++) {
+      if ($Headers[$i]=~/^content-type: *(.*)$/i) {
+        $ContType = $1; splice(@Headers, $i, 1); $i--;
+        next;
+      }
+      if ($Headers[$i]=~m/^location: /i) {
+        $Redirected = 1;
+      }
+    }
+    if (!$Redirected) {
+      push(@Headers, "Content-type: $ContType");
+      my $headers = join("\n",@Headers)."\n\n";
+      # Prepend the output buffer with headers data.
+      # So we output the buffer and headers in ONE print call (it is 
+      # more transparent for calling code if it ties STDOUT by himself).
+      $$rRootBuf = $headers.$$rRootBuf;
+    } else {
+      # Only headers should be sent. 
+      my $headers = join("\n",@Headers)."\n\n";
+      _RealPrint($headers);
+    }
+    $HeadersSent = 1;
+  }
+  #     
+  _Debug("Flush: len=%d", length($$rRootBuf));
+  if (!$Redirected) { 
+    _RealPrint($$rRootBuf);
+  }
+  $$rRootBuf = "";
+  return 1;
 }
 
 
 # constructor new($refToNewBuf=undef)
 #     .
 sub new
-{	my ($class, $rBuf)=@_;
-	$rBuf = \(my $b="") if !defined $rBuf;
-	my $this = bless {
-		rPrevBuf => $rCurBuf,
-		rCurBuf  => $rBuf,
-	}, $class;
-	$rCurBuf = $rBuf;
-	_Debug("[%s] New: prevSt=%s, curSt=%s", $this, $this->{rPrevBuf}, $this->{rCurBuf});
-	return $this;
+{ my ($class, $rBuf)=@_;
+  $rBuf = \(my $b="") if !defined $rBuf;
+  my $this = bless {
+    rPrevBuf => $rCurBuf,
+    rCurBuf  => $rBuf,
+  }, $class;
+  $rCurBuf = $rBuf;
+  _Debug("[%s] New: prevSt=%s, curSt=%s", $this, $this->{rPrevBuf}, $this->{rCurBuf});
+  return $this;
 }
 
 
 #     
 sub DESTROY
-{	my ($this)=@_;
-	_Debug("[%s] DESTROY: prevSt=%s, curSt=%s", $this, $this->{rPrevBuf}, $this->{rCurBuf});
+{ my ($this)=@_;
+  _Debug("[%s] DESTROY: prevSt=%s, curSt=%s", $this, $this->{rPrevBuf}, $this->{rCurBuf});
 
-	#    ,   ,   
-	#     .  ,    
-	#    ,   DESTROY  ,  
-	# STDOUT,       (    -  ).
-	#      , , ,  Perl 
-	#  ,      ,  
-	#  ...     ,    
-	#   .      , 
-	#  STDOUT.    ,       
-	#  , ,    . , ,  
-	#  .
-	if ($rCurBuf == $rRootBuf) {
-		#       print  STDOUT,  
-		#      STDOUT     "", 
-		# Perl- ,  ,   GP Fault.
-		&__PrintAllErrors() if @Errors;
-		Flush();
-		return;
-	}
-	$rCurBuf = $this->{rPrevBuf};
+  #    ,   ,   
+  #     .  ,    
+  #    ,   DESTROY  ,  
+  # STDOUT,       (    -  ).
+  #      , , ,  Perl 
+  #  ,      ,  
+  #  ...     ,    
+  #   .      , 
+  #  STDOUT.    ,       
+  #  , ,    . , ,  
+  #  .
+  if ($rCurBuf == $rRootBuf) {
+    #       print  STDOUT,  
+    #      STDOUT     "", 
+    # Perl- ,  ,   GP Fault.
+    &__PrintAllErrors() if @Errors;
+    Flush();
+    return;
+  }
+  $rCurBuf = $this->{rPrevBuf};
 }
 
 
 # string method buf()
 #       .
 sub buf { 
-	return ${$_[0]->{rCurBuf}};
+  return ${$_[0]->{rCurBuf}};
 }
 
 
@@ -294,17 +295,17 @@ sub buf {
 # constructor _newRoot()
 # Creates the new ROOT (!!!) buffer. Called internally while tying STDOUT.
 sub _newRoot {
-	$$rRootBuf = "";
-	$rCurBuf = undef;
-	goto &new;
+  $$rRootBuf = "";
+  $rCurBuf = undef;
+  goto &new;
 }
 
 
 # Package import.
 sub import {
-	my ($pkg, $needRestart)=@_;
-	retieSTDOUT($needRestart);
-	goto &Exporter::import;
+  my ($pkg, $needRestart)=@_;
+  retieSTDOUT($needRestart);
+  goto &Exporter::import;
 }
 
 
@@ -314,55 +315,55 @@ sub import {
 # (  - ),        
 #  (. _RealPrint).
 sub END {
-	return if !tied(*STDOUT) || ref tied(*STDOUT) ne __PACKAGE__."::Tie";
-	CGI::WebOut::_Debug("CGI::WebOut::END");
-	my $this = tied(*STDOUT);
-	my ($handle, $obj) = ($this->{handle}, $this->{prevObj});
-	CGI::WebOut::Tie::tieobj(*$handle, $obj) 
+  return if !tied(*STDOUT) || ref tied(*STDOUT) ne __PACKAGE__."::Tie";
+  CGI::WebOut::_Debug("CGI::WebOut::END");
+  my $this = tied(*STDOUT);
+  my ($handle, $obj) = ($this->{handle}, $this->{prevObj});
+  CGI::WebOut::Tie::tieobj(*$handle, $obj) 
 }
 
 
 # static _RealPrint()
 # Prints the data to "native" STDOUT handler.
-sub _RealPrint {	
-	my $obj = tied(*STDOUT);
-	_Debug("_RealPrint: STDOUT tied: %s", $obj);
-	my $txt = join("", @_);
-	return if $txt eq "";
-	if ($obj) { 
-		if (ref $obj eq "CGI::WebOut::Tie") {
-			return $obj->parentPrint(@_) 
-		} else {
-			print STDOUT @_;
-		}
-	} else {
-		# Sometimes, during global destruction, STDOUT is already untied
-		# but print still does not work. I don't know, why. This workaround
-		# works always.
-		open(local *H, ">&STDOUT");
-		return print H @_;
-	}
+sub _RealPrint {  
+  my $obj = tied(*STDOUT);
+  _Debug("_RealPrint: STDOUT tied: %s", $obj);
+  my $txt = join("", @_);
+  return if $txt eq "";
+  if ($obj) { 
+    if (ref $obj eq "CGI::WebOut::Tie") {
+      return $obj->parentPrint(@_) 
+    } else {
+      print STDOUT @_;
+    }
+  } else {
+    # Sometimes, during global destruction, STDOUT is already untied
+    # but print still does not work. I don't know, why. This workaround
+    # works always.
+    open(local *H, ">&STDOUT");
+    return print H @_;
+  }
 }
 
 
 #   -    
 my $opened;
-sub _Debug {	
-	return if !$DEBUG;
-	my ($msg, @args) = @_;
+sub _Debug {  
+  return if !$DEBUG;
+  my ($msg, @args) = @_;
 
-	# Detect "global destruction" stage.
-	my $gd = '';
-	{
-		local $SIG{__WARN__} = sub { $gd .= $_[0] };
-		warn("test");
-		$gd =~ s/^.*? at \s+ .*? \s+ line \s+ \d+ \s+//sx;
-		$gd =~ s/^\s+|[\s.]+$//sg;
-		$gd = undef if $gd !~ /global\s*destruction/i;
-	}
-	local $^W;
-	open(local *F, ($opened++? ">>" : ">").$DEBUG); 
-	print F sprintf($msg, map { defined $_? $_ : "undef" } @args) . ($gd? "($gd)" : "")."\n";
+  # Detect "global destruction" stage.
+  my $gd = '';
+  {
+    local $SIG{__WARN__} = sub { $gd .= $_[0] };
+    warn("test");
+    $gd =~ s/^.*? at \s+ .*? \s+ line \s+ \d+ \s+//sx;
+    $gd =~ s/^\s+|[\s.]+$//sg;
+    $gd = undef if $gd !~ /global\s*destruction/i;
+  }
+  local $^W;
+  open(local *F, ($opened++? ">>" : ">").$DEBUG); binmode(F);
+  print F sprintf($msg, map { defined $_? $_ : "undef" } @args) . ($gd? " ($gd)" : "")."\n";
 }
 
 
@@ -402,8 +403,8 @@ package CGI::WebOut::Tie;
 
 # The same as tie(), but ties existed object to the handle.
 sub tieobj { 
-#	return $_[1]? tie($_[0], "CGI::WebOut::TieMediator", $_[1]) : untie($_[0]); 
-	return tie($_[0], "CGI::WebOut::TieMediator", $_[1]); 
+# return $_[1]? tie($_[0], "CGI::WebOut::TieMediator", $_[1]) : untie($_[0]); 
+  return tie($_[0], "CGI::WebOut::TieMediator", $_[1]); 
 }
 
 ## Fully overriden methods.
@@ -414,28 +415,28 @@ sub PRINTF { shift; return CGI::WebOut::echo(sprintf(@_)); }
 # Creates the new tie. Saves the old object and handle reference.
 # See synopsis above.
 sub TIEHANDLE 
-{	my ($cls, $handle, $prevObj) = @_;
-	CGI::WebOut::_Debug("TIEHANDLE(%s, %s, %s)", $cls, $handle, $prevObj);
-	return bless { 
-		handle  => $handle,
-		prevObj => $prevObj,
-		outObj  => CGI::WebOut->_newRoot($rRootBuf),
-	}, $cls;
+{ my ($cls, $handle, $prevObj) = @_;
+  CGI::WebOut::_Debug("TIEHANDLE(%s, %s, %s)", $cls, $handle, $prevObj);
+  return bless { 
+    handle  => $handle,
+    prevObj => $prevObj,
+    outObj  => CGI::WebOut->_newRoot($rRootBuf),
+  }, $cls;
 }
 
 sub DESTROY {
-	CGI::WebOut::_Debug("[%s] DESTROY", $_[0]);
+  CGI::WebOut::_Debug("[%s] DESTROY", $_[0]);
 }
 
 ## Methods, inherited from parent.
 sub CLOSE 
-{	my ($this) = @_;
-	CGI::WebOut::Flush();
-	$this->parentCall(sub { close(*{$this->{handle}}) });
+{ my ($this) = @_;
+  CGI::WebOut::Flush();
+  $this->parentCall(sub { close(*{$this->{handle}}) });
 }
 sub BINMODE 
-{ 	my ($this) = @_;
-	$this->parentCall(sub { binmode(*{$this->{handle}}) });
+{   my ($this) = @_;
+  $this->parentCall(sub { binmode(*{$this->{handle}}) });
 }
 
 # Untie process is fully transparent for parent. For example, code:
@@ -449,28 +450,28 @@ sub BINMODE
 # in UNTIE() - when the sub finishes, Perl hardly remove tie. 
 our $doNotUntie = 0;
 sub UNTIE
-{	my ($this, $nRef) = @_;
-	return if $doNotUntie;
-	my $handle = $this->{handle};
-	CGI::WebOut::_Debug("UNTIE prev=%s, cur=%s", $this->{prevObj}, tied(*$handle));
-	# Destroy output object BEFORE untie parent.
-	$this->{outObj} = undef;
-	# Untie parent object.
-	if ($this->{prevObj}) {
-		tieobj(*$handle, $this->{prevObj});
-		$this->{prevObj} = undef; # release ref
-		untie(*$handle); # call parent untie
-		$this->{prevObj} = tied(*$handle);
-	}
+{ my ($this, $nRef) = @_;
+  return if $doNotUntie;
+  my $handle = $this->{handle};
+  CGI::WebOut::_Debug("UNTIE prev=%s, cur=%s", $this->{prevObj}, tied(*$handle));
+  # Destroy output object BEFORE untie parent.
+  $this->{outObj} = undef;
+  # Untie parent object.
+  if ($this->{prevObj}) {
+    tieobj(*$handle, $this->{prevObj});
+    $this->{prevObj} = undef; # release ref
+    untie(*$handle); # call parent untie
+    $this->{prevObj} = tied(*$handle);
+  }
 }
 
 # void method parentPrint(...)
 # Prints using parent print method.
 sub parentPrint
-{	my $this = shift;
-	my $params = \@_;
-	CGI::WebOut::_Debug("parentPrint('%s')", join "", @$params);
-	$this->parentCall(sub { print STDOUT @$params });
+{ my $this = shift;
+  my $params = \@_;
+  CGI::WebOut::_Debug("parentPrint('%s')", join "", @$params);
+  $this->parentCall(sub { print STDOUT @$params });
 }
 
 # void method parentCall($codeRef)
@@ -478,26 +479,26 @@ sub parentPrint
 # After call context is switched back, as if nothing has happened.
 # Returns the same that $codeRef had returned.
 sub parentCall
-{	my ($this, $sub) = @_;
-	my ($handle, $obj) = ($this->{handle}, $this->{prevObj});
-	my $save = tied(*$handle);
-	if ($obj) {
-		tieobj(*$handle, $obj) 
-	} elsif ($save) {
-		local $doNotUntie = 1;
-		local $^W;
-		untie(*$handle);
-	}
-	CGI::WebOut::_Debug("parentCall for STDOUT=%s", $obj);
-	my @result = eval { wantarray? $sub->() : scalar $sub->() };
-	if ($save) {
-		tieobj(*$handle, $save);
-	} elsif ($obj) {
-		local $doNotUntie = 1;
-		local $^W;
-		untie(*$handle);
-	}
-	return wantarray? @result : $result[0];
+{ my ($this, $sub) = @_;
+  my ($handle, $obj) = ($this->{handle}, $this->{prevObj});
+  my $save = tied(*$handle);
+  if ($obj) {
+    tieobj(*$handle, $obj) 
+  } elsif ($save) {
+    local $doNotUntie = 1;
+    local $^W;
+    untie(*$handle);
+  }
+  CGI::WebOut::_Debug("parentCall for STDOUT=%s", $obj);
+  my @result = eval { wantarray? $sub->() : scalar $sub->() };
+  if ($save) {
+    tieobj(*$handle, $save);
+  } elsif ($obj) {
+    local $doNotUntie = 1;
+    local $^W;
+    untie(*$handle);
+  }
+  return wantarray? @result : $result[0];
 }
 }}}
 
@@ -519,45 +520,45 @@ sub parentCall
 # }
 #  catch  warnings        .
 sub try (&;@) 
-{	my ($try,@Hand) = @_;
-	#     local   @Errors   .
-	#   &$try  ,     exit(),
-	#    try()     .     
-	# local,     @Errors  .   
-	#    ,   @Errors   
-	#     .
-	my @SvErrors = @Errors;
-	#  try-
-	my @Result = eval { &$try };
-	#   ,       exit().
-	#          .
-	#    .    
-	#   local,       
-	# warnings- (. ).
-	local @Warns = @Errors>@SvErrors? @Errors[@SvErrors..$#Errors] : ();
-	#    
-	@Errors = @SvErrors;
-	#      
-	map { &$_() } @Hand;
-	#  ,   try-
-	return wantarray? @Result: $Result[0];
+{ my ($try,@Hand) = @_;
+  #     local   @Errors   .
+  #   &$try  ,     exit(),
+  #    try()     .     
+  # local,     @Errors  .   
+  #    ,   @Errors   
+  #     .
+  my @SvErrors = @Errors;
+  #  try-
+  my @Result = eval { &$try };
+  #   ,       exit().
+  #          .
+  #    .    
+  #   local,       
+  # warnings- (. ).
+  local @Warns = @Errors>@SvErrors? @Errors[@SvErrors..$#Errors] : ();
+  #    
+  @Errors = @SvErrors;
+  #      
+  map { &$_() } @Hand;
+  #  ,   try-
+  return wantarray? @Result: $Result[0];
 }
 
 #  -,    catch-.
 sub catch(&;@) 
-{	my ($body, @Hand)=@_;
-	return (sub { if($@) { chomp($@); local $_=$@; &$body($_) } }, @Hand);
+{ my ($body, @Hand)=@_;
+  return (sub { if($@) { chomp($@); local $_=$@; &$body($_) } }, @Hand);
 }
 
 #  -,    warnings-.
 sub warnings(&;@) 
-{	my ($body,@Hand)=@_;
-	return (sub { &$body(@Warns) }, @Hand);
+{ my ($body,@Hand)=@_;
+  return (sub { &$body(@Warns) }, @Hand);
 }
 
 #  .
 sub throw($) { 
-	die(ref($_[0])? $_[0] : "$_[0]\n") 
+  die(ref($_[0])? $_[0] : "$_[0]\n") 
 }
 
 
@@ -566,17 +567,17 @@ sub throw($) {
 #   print  echo,  -  (    Flush()).
 #     .
 sub SetAutoflush(;$)
-{	my ($mode)=@_;
-	my $old = $UseAutoflush;
-	if (defined $mode) { $UseAutoflush = $mode; }
-	return $old;
+{ my ($mode)=@_;
+  my $old = $UseAutoflush;
+  if (defined $mode) { $UseAutoflush = $mode; }
+  return $old;
 }
 
 # bool NoAutoflush()
 #      echo.
 #    .
 sub NoAutoflush() {
-	return SetAutoflush(0);
+  return SetAutoflush(0);
 }
 
 
@@ -584,44 +585,44 @@ sub NoAutoflush() {
 #      echo.
 #    .
 sub UseAutoflush() {
-	return SetAutoflush(1);
+  return SetAutoflush(1);
 }
 
 
 #    URL (   )
 sub Redirect($)
-{	my ($url) = @_;
-	$Redirected = Header("Location: $url");
-	exit;
+{ my ($url) = @_;
+  $Redirected = Header("Location: $url");
+  exit;
 }
 
 
 #     URL
 sub ExternRedirect($)
-{	my ($url) = @_;
-	if ($url !~ /^\w+:/) {
-		#  .
-		if ($url !~ m{^/}) {
-			my $sn = $ENV{SCRIPT_NAME};
-			$sn =~ s{/+[^/]*$}{}sg;
-			$url = "$sn/$url";
-		}
-		#   .
-		$url = "http://$ENV{SERVER_NAME}$url";
-	}
-	$Redirected = Header("Location: $url");
-	exit;
+{ my ($url) = @_;
+  if ($url !~ /^\w+:/) {
+    #  .
+    if ($url !~ m{^/}) {
+      my $sn = $ENV{SCRIPT_NAME};
+      $sn =~ s{/+[^/]*$}{}sg;
+      $url = "$sn/$url";
+    }
+    #   .
+    $url = "http://$ENV{SERVER_NAME}$url";
+  }
+  $Redirected = Header("Location: $url");
+  exit;
 }
 
 
 #    
 sub NoCache()
-{	return 1 if $NoCached++;
-	Header("Expires: Mon, 26 Jul 1997 05:00:00 GMT") or return undef;
-	Header("Last-Modified: ".gmtime(time)." GMT") or return undef;
-	Header("Cache-Control: no-cache, must-revalidate") or return undef;
-	Header("Pragma: no-cache") or return undef;
-	return 1;
+{ return 1 if $NoCached++;
+  Header("Expires: Mon, 26 Jul 1997 05:00:00 GMT") or return undef;
+  Header("Last-Modified: ".gmtime(time)." GMT") or return undef;
+  Header("Cache-Control: no-cache, must-revalidate") or return undef;
+  Header("Pragma: no-cache") or return undef;
+  return 1;
 }
 
 
@@ -633,17 +634,17 @@ sub NoCache()
 #    ,   .
 #    .
 sub ErrorReporting(;$)
-{	my ($lev)=@_;
-	my $old = $ErrorReporting;
-	$ErrorReporting = $lev if defined $lev;
-	return $old;
+{ my ($lev)=@_;
+  my $old = $ErrorReporting;
+  $ErrorReporting = $lev if defined $lev;
+  return $old;
 }
 
 
 #       .
 sub Warning($)
-{	my ($msg)=@_;
-	push(@Errors, $msg);
+{ my ($msg)=@_;
+  push(@Errors, $msg);
 }
 
 
@@ -651,42 +652,42 @@ sub Warning($)
 #     ,  STDOUT   "" , 
 #   print !!!
 sub __PrintAllErrors()
-{	local $^W = undef;
-	# http://forum.dklab.ru/perl/symbiosis/Fastcgi+WeboutUtechkaPamyati.html
-	if(!@Errors || !$ErrorReporting){
-		@Errors=(); 
-        	return ; 
-	}
-	if (IsWebMode) {
-		if ($ErrorReporting == ER_Err2Browser) {
-			#  ,    ...
-			echo "</script>","</table>"x6,"</pre>"x3,"</tt>"x2,"</i>"x2,"</b>"x2;
-		}
-		my %wasErr=();
-		for (my $i=0; $i<@Errors; $i++) {
-			chomp(my $st = $Errors[$i]); 
-			#      .
-			next if $wasErr{$st};
-			$wasErr{$st}=1 if $st =~ /^Fatal:/;
-			#  .
-			if ($ErrorReporting == ER_Err2Browser) {
-				$st=~s/>/&gt;/sg;
-				$st=~s/</&lt;/sg;
-				$st=~s|^([a-zA-Z]+:)|<b>$1</b>|mgx;
-				$st=~s|\n|<br>\n&nbsp;&nbsp;&nbsp;&nbsp;|g; 
-				my $s=$i+1;
-				for(my $i=length($s); $i<length(scalar(@Errors)); $i++) { $s="&nbsp;$s" }
-        		echo "<b><tt>$s)</tt></b> $st<br>\n"; 
-			} elsif ($ErrorReporting == ER_Err2Comment) {
-        		echo "\n<!-- $st -->"; 
-			} elsif ($ErrorReporting == ER_Err2Plain) {
-        		echo "\n$st"; 
-			}
-		}
-	} else {
-		foreach my $st (@Errors) { chomp($st); echo "\n$st" }
-	}
-	@Errors=();
+{ local $^W = undef;
+  # http://forum.dklab.ru/perl/symbiosis/Fastcgi+WeboutUtechkaPamyati.html
+  if(!@Errors || !$ErrorReporting){
+    @Errors=(); 
+          return ; 
+  }
+  if (IsWebMode) {
+    if ($ErrorReporting == ER_Err2Browser) {
+      #  ,    ...
+      echo "</script>","</table>"x6,"</pre>"x3,"</tt>"x2,"</i>"x2,"</b>"x2;
+    }
+    my %wasErr=();
+    for (my $i=0; $i<@Errors; $i++) {
+      chomp(my $st = $Errors[$i]); 
+      #      .
+      next if $wasErr{$st};
+      $wasErr{$st}=1 if $st =~ /^Fatal:/;
+      #  .
+      if ($ErrorReporting == ER_Err2Browser) {
+        $st=~s/>/&gt;/sg;
+        $st=~s/</&lt;/sg;
+        $st=~s|^([a-zA-Z]+:)|<b>$1</b>|mgx;
+        $st=~s|\n|<br>\n&nbsp;&nbsp;&nbsp;&nbsp;|g; 
+        my $s=$i+1;
+        for(my $i=length($s); $i<length(scalar(@Errors)); $i++) { $s="&nbsp;$s" }
+            echo "<b><tt>$s)</tt></b> $st<br>\n"; 
+      } elsif ($ErrorReporting == ER_Err2Comment) {
+            echo "\n<!-- $st -->"; 
+      } elsif ($ErrorReporting == ER_Err2Plain) {
+            echo "\n$st"; 
+      }
+    }
+  } else {
+    foreach my $st (@Errors) { chomp($st); echo "\n$st" }
+  }
+  @Errors=();
 }
 
 return 1;
@@ -763,10 +764,10 @@ but Rasmus does not think so.
   use CGI::WebOut;
   my $str=grab {
     print "Hi there!\n";
-	# Nested grab!
-	my $s=grab {
-		print "This string will be redirect to variable!";
-	}
+  # Nested grab!
+  my $s=grab {
+    print "This string will be redirect to variable!";
+  }
   }
   $str=~s/\n/<br>/sg;
 
@@ -776,7 +777,7 @@ but Rasmus does not think so.
     DoSomeDangerousStuff();
   } catch {
     print "An error occured: $_";
-	throw "Error";
+  throw "Error";
   } warnings {
     print "Wanning & error messages:".join("\n",@_);
   };
